@@ -2,8 +2,6 @@ import json
 import os
 import shutil
 
-import six
-
 from stone.backends.obj_c import (
     base_file_comment,
     comment_prefix,
@@ -915,7 +913,7 @@ class ObjCTypesBackend(ObjCBaseBackend):
                          if data_type.min_length else 'nil'),
                         ('maxLength', '@({})'.format(data_type.max_length)
                          if data_type.max_length else 'nil'),
-                        ('pattern', '@"{}"'.format(six.ensure_str(pattern))
+                        ('pattern', '@"{}"'.format(str(pattern))
                          if pattern else 'nil'),
                     ]))
 
@@ -1006,7 +1004,7 @@ class ObjCTypesBackend(ObjCBaseBackend):
                         self.emit(
                             'jsonDict[@".tag"] = @"{}";'.format(fmt_var(tag)))
                 self.emit()
-            self.emit('return [jsonDict count] > 0 ? jsonDict : nil;')
+            self.emit('return jsonDict;')
         self.emit()
 
     def _generate_struct_deserializer(self, struct):
@@ -1152,7 +1150,7 @@ class ObjCTypesBackend(ObjCBaseBackend):
                     )
 
             self.emit()
-            self.emit('return [jsonDict count] > 0 ? jsonDict : nil;')
+            self.emit('return jsonDict;')
 
         self.emit()
 
